@@ -4,7 +4,7 @@
 #' polygons. For each polygon, the desired statistic/s (mean, median or sd)
 #' is/are returned.
 #' The required resources for this indicator are:
-#'  - [srtmdem]
+#'  - [nasa_srtm]
 #'
 #' The following arguments can be set:
 #' \describe{
@@ -43,7 +43,7 @@
 #'       cores = 1,
 #'       verbose = FALSE
 #'     ) %>%
-#'     get_resources("srtmdem") %>%
+#'     get_resources("nasa_srtm") %>%
 #'     calc_indicators("elevation",
 #'       stats_elevation = c("mean", "median", "sd", "var"), engine = "extract"
 #'     ) %>%
@@ -59,7 +59,7 @@ NULL
 #' terra, or exactextract from exactextractr as desired.
 #'
 #' @param shp A single polygon for which to calculate the elevation statistic
-#' @param srtmdem The elevation raster resource from SRTM
+#' @param nasa_srtm The elevation raster resource from SRTM
 #' @param stats Function to be applied to compute statistics for polygons either
 #'   one or multiple inputs as character "mean", "median" or "sd".
 #' @param engine The preferred processing functions from either one of "zonal",
@@ -73,19 +73,19 @@ NULL
 #' @keywords internal
 #' @noRd
 
-.calc_dem <- function(shp,
-                      srtmdem,
-                      engine = "zonal",
-                      stats_elevation = "mean",
-                      rundir = tempdir(),
-                      verbose,
-                      todisk = FALSE,
-                      ...) {
-  if (is.null(srtmdem)) {
+.calc_elevation <- function(shp,
+                            nasa_srtm,
+                            engine = "zonal",
+                            stats_elevation = "mean",
+                            rundir = tempdir(),
+                            verbose,
+                            todisk = FALSE,
+                            ...) {
+  if (is.null(nasa_srtm)) {
     return(NA)
   }
   # check if intermediate raster should be written to disk
-  if (ncell(srtmdem) > 1024 * 1024) todisk <- TRUE
+  if (ncell(nasa_srtm) > 1024 * 1024) todisk <- TRUE
   # check if input engine is correctly specified
   available_engines <- c("zonal", "extract", "exactextract")
   .check_engine(available_engines, engine)
@@ -95,21 +95,21 @@ NULL
 
   if (engine == "extract") {
     tibble_zstats <- .comp_dem_extract(
-      elevation = srtmdem,
+      elevation = nasa_srtm,
       shp = shp,
       stats = stats_elevation
     )
     return(tibble_zstats)
   } else if (engine == "exactextract") {
     tibble_zstats <- .comp_dem_exact_extractr(
-      elevation = srtmdem,
+      elevation = nasa_srtm,
       shp = shp,
       stats = stats_elevation
     )
     return(tibble_zstats)
   } else {
     tibble_zstats <- .comp_dem_zonal(
-      elevation = srtmdem,
+      elevation = nasa_srtm,
       shp = shp,
       stats = stats_elevation,
       todisk = todisk,
